package com.clx.performance.dao.export;

import com.clx.performance.mapper.export.ExportTemplateMapper;
import com.clx.performance.model.export.ExportTemplate;
import com.msl.common.base.Optional;
import com.msl.common.dao.BaseDao;

import java.util.List;

public interface ExportTemplateDao extends BaseDao<ExportTemplateMapper, ExportTemplate, Integer> {


    /**
     * 根据功能code查询某用户下的模板列表
     *
     * @param userNo       用户编码
     * @param functionCode 功能code
     * @return
     */
    List<ExportTemplate> listUserFunctionTemplate(Long userNo, String functionCode);

    /**
     * 根据名称查询用户在某功能下的模板
     *
     * @param userNo       用户编码
     * @param functionCode 功能code
     * @param name         模板名称
     * @return
     */
    Optional<ExportTemplate> getUserFunctionTemplateByName(Long userNo, String functionCode, String name);

    /**
     * 根据功能code集合查询某用户下的模板列表
     *
     * @param userNo        用户编码
     * @param functionCodes 功能code集合
     * @return
     */
    List<ExportTemplate> listUserFunctionsTemplate(Long userNo, List<String> functionCodes);

    /**
     * 根据id查询模板
     *
     * @param id 模板id
     * @return
     */
    Optional<ExportTemplate> getById(Integer id);

    /**
     * 新增模板
     *
     * @param template 待新增模板数据
     */
    void saveTemplate(ExportTemplate template);

    /**
     * 删除模板
     *
     * @param id 模板id
     */
    void deleteTemplate(Integer id);

    /**
     * 修改模板名称
     *
     * @param id   模板id
     * @param name 模板名称
     */
    void updateTemplateName(Integer id, String name);

    /**
     * 去除用户在某个功能下的默认模板
     *
     * @param userNo       用户编码
     * @param functionCode 功能code
     */
    void updateTemplateNotDefault(Long userNo, String functionCode);

    /**
     * 设置模板为默认模板
     *
     * @param templateId 默认模板
     */
    void updateTemplateDefault(Integer templateId);

    /**
     * 统计用户在某个功能下的模板数量
     *
     * @param userNo       用户编码
     * @param functionCode 功能code
     */
    long countUserFunctionTemplate(Long userNo, String functionCode);
}
