package com.clx.performance.dao.impl.export;

import com.clx.performance.dao.export.ExportFieldDao;
import com.clx.performance.mapper.export.ExportFieldMapper;
import com.clx.performance.model.export.ExportField;
import com.msl.common.base.Optional;
import com.msl.common.dao.impl.BaseDaoImpl;
import com.msl.common.enums.WhetherEnum;
import org.springframework.stereotype.Repository;

import java.util.Collections;
import java.util.List;

@Repository
public class ExportFieldDaoImpl extends BaseDaoImpl<ExportFieldMapper, ExportField, Integer> implements ExportFieldDao {


    /**
     * 查询模板下的所有字段
     *
     * @param templateId 模板id
     * @return 模板字段列表
     */
    @Override
    public List<ExportField> listFieldByTemplate(Integer templateId) {
        return Optional.ofNullable(templateId).map(baseMapper::listFieldByTemplate).orElse(Collections.emptyList());
    }

    /**
     * 查询功能下的所有字段
     *
     * @param functionCode 功能code
     * @return 字段列表
     */
    @Override
    public List<ExportField> listFieldByFunctionCode(String functionCode) {
        return Optional.ofNullable(functionCode)
                .map(code -> lQrWrapper().eq(ExportField::getExportFunctionCode, functionCode)
                        .orderByAsc(ExportField::getSort))
                .map(super::list)
                .orElse(Collections.emptyList());
    }

    /**
     * 查询公司该功能下的所有字段
     *
     * @param functionCode 功能code
     * @param companyNo    companyNo
     * @return 字段列表
     */
    @Override
    public List<ExportField> listFieldByFunctionCode(String functionCode, Long companyNo) {
        return Optional.ofNullable(functionCode)
                .map(code -> lQrWrapper().eq(ExportField::getExportFunctionCode, functionCode)
                        .eq(ExportField::getCompanyNo, companyNo)
                        .orderByAsc(ExportField::getSort))
                .map(super::list)
                .orElse(Collections.emptyList());
    }

    /**
     * 查询功能下的所有必填字段
     *
     * @param functionCode 功能code
     * @return 字段列表
     */
    @Override
    public List<ExportField> listRequiredFieldByFunctionCode(String functionCode) {
        return Optional.ofNullable(functionCode)
                .map(code -> lQrWrapper().eq(ExportField::getExportFunctionCode, functionCode)
                        .eq(ExportField::getRequired, WhetherEnum.get(true))
                        .orderByAsc(ExportField::getSort))
                .map(super::list)
                .orElse(Collections.emptyList());
    }
}
