package com.clx.performance.service.export;

import com.clx.performance.param.pc.export.SaveExportTemplateParam;
import com.clx.performance.vo.pc.export.ExportFieldVo;
import com.clx.performance.vo.pc.export.ExportTemplateDetailVo;
import com.clx.performance.vo.pc.export.ExportTemplateVo;
import com.msl.common.base.Optional;

import java.util.List;

public interface ExportFieldService {


    /**
     * 查询用户某功能下的模板列表
     *
     * @param userNo       用户编码
     * @param functionCode 功能code
     * @return 模板列表
     */
    List<ExportTemplateVo> listUserFunctionTemplate(Long userNo, String functionCode);

    /**
     * 查询用户某些功能下的模板列表
     *
     * @param userNo        用户编码
     * @param functionCodes 功能code集合
     * @return 模板列表
     */
    List<ExportTemplateVo> listUserFunctionsTemplate(Long userNo, List<String> functionCodes);

    /**
     * 根据id获取模板详情
     *
     * @param id 模板id
     * @return 模板详情
     */
    Optional<ExportTemplateDetailVo> getTemplateDetail(Integer id);

    /**
     * 查询模板下的所有字段
     *
     * @param templateId 模板id
     * @return 模板字段列表
     */
    List<ExportFieldVo> listFieldByTemplate(Integer templateId);

    /**
     * 查询模板下的所有字段
     *
     * @param templateId 模板id
     * @return 模板字段列表
     */
    List<ExportFieldVo> listFieldByTemplateAndDate(Integer templateId, String date);

    /**
     * 新增模板
     *
     * @param param 模板参数
     * @return 模板id
     */
    Integer saveTemplate(SaveExportTemplateParam param);

    /**
     * 删除模板
     *
     * @param id 模板id
     */
    void deleteTemplate(Integer id);

    /**
     * 修改模板名称
     *
     * @param templateId 模板id
     * @param name       模板名称
     */
    void updateTemplateName(Integer templateId, String name);

    /**
     * 设置默认模板
     *
     * @param templateId 模板id
     */
    void updateTemplateDefaultFlag(Integer templateId);

    /**
     * 修改模板的字段列表
     *
     * @param id       模板id
     * @param fieldIds 字段列表
     */
    void updateTemplateFields(Integer id, List<Integer> fieldIds);

    /**
     * 查询功能下的所有字段
     *
     * @param functionCode 功能code
     * @return 字段列表
     */
    List<ExportFieldVo> listFieldByFunctionCode(String functionCode);

    /**
     * 查询功能下的所有字段
     *
     * @param functionCode 功能code
     * @return 字段列表
     */
    List<ExportFieldVo> listFieldByFunctionCodeWithBase(String functionCode, String date);
}
